@@ -20,7 +20,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_batch.type_defs import (
     DescribeComputeEnvironmentsResponseTypeDef,
@@ -51,7 +51,7 @@ class DescribeComputeEnvironmentsPaginator(Boto3Paginator):
 
     def paginate(
         self, computeEnvironments: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeComputeEnvironmentsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeComputeEnvironmentsResponseTypeDef]:
         """
         [DescribeComputeEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments.paginate)
         """
@@ -68,7 +68,7 @@ class DescribeJobDefinitionsPaginator(Boto3Paginator):
         jobDefinitionName: str = None,
         status: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeJobDefinitionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeJobDefinitionsResponseTypeDef]:
         """
         [DescribeJobDefinitions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions.paginate)
         """
@@ -81,7 +81,7 @@ class DescribeJobQueuesPaginator(Boto3Paginator):
 
     def paginate(
         self, jobQueues: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeJobQueuesResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeJobQueuesResponseTypeDef]:
         """
         [DescribeJobQueues.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/batch.html#Batch.Paginator.DescribeJobQueues.paginate)
         """
@@ -101,7 +101,7 @@ class ListJobsPaginator(Boto3Paginator):
             "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
         ] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListJobsResponseTypeDef]:
         """
         [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/batch.html#Batch.Paginator.ListJobs.paginate)
         """
